@@ -4,7 +4,9 @@
 #' @param input_id String. The input identifier used to access the value.
 #' @param label String. The radio button label.
 #' @param choices Named vector. The option names and underyling values.
+#' @param selected The initially selected value (if not specified then defaults to the first value).
 #' @param color String. The color of the radio buttons. Leave empty for the default color. Visit \url{http://materializecss.com/color.html} for a list of available colors. \emph{This input requires using color hex codes, rather than the word form. E.g., "#ef5350", rather than "red lighten-1".}
+#' @param with_gap Boolean. To create a radio button with a gap.
 #' @examples
 #' material_radio_button(
 #'   input_id = "example_radio_button",
@@ -16,7 +18,7 @@
 #'   ),
 #'   color = "#ef5350"
 #' )
-material_radio_button <- function(input_id, label, choices, color = NULL) {
+material_radio_button <- function(input_id, label, choices, selected = NULL, color = NULL, with_gap = FALSE) {
   
   if(!is.null(color)){
     
@@ -47,28 +49,26 @@ material_radio_button <- function(input_id, label, choices, color = NULL) {
   material_radio_choices <- shiny::tagList()
   
   has_names <- !is.null(names(choices))
+  choices[choices == ""] <- "_shinymaterialradioempty_"
+  selected <- if (is.null(selected)) choices[[1]] else as.character(selected)
+  if (length(selected) > 1) stop("The 'selected' argument must be of length 1")
+  if (! selected %in% choices) stop("The 'selected' argument must be in choices")
   
   for(i in 1:length(choices)){
     material_radio_choices[[i]] <-
       shiny::tags$p(
         shiny::tags$input(
+          class = if (with_gap) "with-gap",
           type = "radio",
           name = input_id,
-          class = 
-            ifelse(
-              is.null(color),
-              '', 
-              paste0('shinymaterial-radio-button-', input_id)
-            ),
-          id = ifelse(choices[i] != "", choices[i], "_shinymaterialradioempty_")
+          class = if (!is.null(color)) 
+            paste0('shinymaterial-radio-button-', input_id),
+          id = choices[i],
+          checked = if(choices[i] %in% selected) "checked"
         ),
         shiny::tags$label(
-          `for` = ifelse(choices[i] != "", choices[i], "_shinymaterialradioempty_"),
-          ifelse(
-            has_names,
-            names(choices[i]),
-            choices[i]
-          )
+          `for` = choices[i],
+          ifelse(has_names, names(choices[i]), choices[i])
         )
       )
   }
