@@ -74,7 +74,8 @@ material_side_nav_tabs <- function(side_nav_tabs, icons = NULL, color = NULL, fo
             "$('#", side_nav_tabs[[i]], "').show();",
             "$('#", side_nav_tabs[[i]], "').trigger('show');",
             "$('#", side_nav_tabs[[i]], "').trigger('shown');",
-            "$('#", paste0(side_nav_tabs[[i]], "_tab_id"), "').addClass('active');"
+            "$('#", paste0(side_nav_tabs[[i]], "_tab_id"), "').addClass('active');",
+            "$('#side_nav_tabs_click_info').trigger('click');"
           ),
           icon_tag.i, names(side_nav_tabs)[[i]]
         )
@@ -82,6 +83,7 @@ material_side_nav_tabs <- function(side_nav_tabs, icons = NULL, color = NULL, fo
   }
   
   shiny::tagList(
+    shiny::tags$div(id = "side_nav_tabs_click_info"),
     material_side_nav_tabs
   )
 }
