@@ -7,6 +7,7 @@ if(interactive()){
       title = "Testing", nav_bar_fixed = TRUE,
       nav_bar_color = 'red lighten-3',
       background_color = "white",
+      include_icons = TRUE, include_fonts = TRUE,
       material_side_nav(
         tags$h4("stuff"),
         background_color = "blue lighten-4"
@@ -30,7 +31,12 @@ if(interactive()){
           button_color = "red lighten-4",
           button_depth = 5,
           shiny::tags$p("Modal Content"),
-          close_button_label = "Close2", display_button = FALSE
+          close_button_label = "Close2", 
+          display_button = FALSE,
+          material_button(
+            input_id = "close_modal2", 
+            label = "TEST CLOSE MODAL"
+          )
         ),
         material_button(input_id = "open_modal2", label = "testmodal"),
         material_tabs(
@@ -364,6 +370,14 @@ if(interactive()){
           input_id = "example_file_input2",
           label = "File"
         ),
+      
+        material_switch(input_id = "update_button_test_switch", 
+                        label = "update_button_test_switch", 
+                        off_label = "No", on_label = "Yes", 
+                        initial_value = TRUE),
+        material_button(input_id = "update_button_test",
+                        label = "test", icon = "cloud"),
+        br(),
         material_button(input_id = "update_text_test_button",
                         label = "update text"),
         material_text_box(input_id = "update_text_test",
@@ -404,7 +418,7 @@ if(interactive()){
         material_button(input_id = "update_radio_button_test_button",
                         label = "update radio button"),
         material_radio_button(input_id = "update_radio_button_test",
-                              label = "text",choices = c("Adf" =  "a_update", "Bdf" = "b_update")),
+                              label = "text",choices = c("Adf" =  "a_update", "Bdf" = "b_update"), with_gap = TRUE),
         plotOutput('testRadioButtonPlot'),
         
         material_button(input_id = "update_slider_test_button",
@@ -442,6 +456,12 @@ if(interactive()){
       open_material_modal(session, "example_modal2")
       }
     })
+    observeEvent(input$close_modal2, {
+      message('this happened')
+      if(input$close_modal2 > 0){
+        close_material_modal(session, "example_modal2")
+      }
+    })
     #button
     observeEvent(input$input_button1, {
       message(input$input_button1)
@@ -565,7 +585,12 @@ if(interactive()){
     observeEvent(input$example_date_picker, {
       message(input$example_date_picker)
     })
-    
+    observe({
+      if (input$update_button_test_switch)
+        update_material_button(session, "update_button_test", "Active", "cloud", FALSE)
+      else
+        update_material_button(session, "update_button_test", "Non Active", "close", TRUE)
+    })
     observeEvent(input$update_text_test_button, {
       
       update_material_text_box(session,
